@@ -23,9 +23,10 @@ SETTINGS_SCHEMA = 'com.github.huluti.Curtail'
 
 
 @Gtk.Template(resource_path=UI_PATH + 'preferences.ui')
-class CurtailPrefsWindow(Adw.PreferencesWindow):
-    __gtype_name__ = 'CurtailPrefsWindow'
+class CurtailPrefsDialog(Adw.PreferencesDialog):
+    __gtype_name__ = 'CurtailPrefsDialog'
 
+    toggle_recursive = Gtk.Template.Child()
     toggle_metadata = Gtk.Template.Child()
     toggle_file_attributes = Gtk.Template.Child()
     toggle_new_file = Gtk.Template.Child()
@@ -45,14 +46,16 @@ class CurtailPrefsWindow(Adw.PreferencesWindow):
         super().__init__(**kwargs)
 
         self.parent = parent
-        self.set_transient_for(parent)
-        self.set_modal(True)
-
         self.build_ui()
 
     def build_ui(self):
         # Compression settings
 
+        # Recursive
+        self.toggle_recursive.set_active(self._settings.get_boolean('recursive'))
+        self.toggle_recursive.connect('notify::active', self.on_bool_changed,
+                                     'recursive')
+
         # Keep metadata
         self.toggle_metadata.set_active(self._settings.get_boolean('metadata'))
         self.toggle_metadata.connect('notify::active', self.on_bool_changed,
@@ -137,3 +140,4 @@ class CurtailPrefsWindow(Adw.PreferencesWindow):
 
     def on_int_changed(self, spin, key):
         self._settings.set_int(key, spin.get_value())
+
