@@ -20,10 +20,11 @@ from urllib.parse import unquote
 from pathlib import Path
 
 from .resultitem import ResultItem
-from .preferences import CurtailPrefsWindow
+from .preferences import CurtailPrefsDialog
 from .compressor import Compressor
 from .tools import add_filechooser_filters, get_file_type, \
-    create_image_from_file, sizeof_fmt, debug_infos, get_image_files_from_folder
+    create_image_from_file, sizeof_fmt, debug_infos, \
+    get_image_files_from_folder, get_image_files_from_folder_recursive
 
 CURTAIL_PATH = '/com/github/huluti/Curtail/'
 SETTINGS_SCHEMA = 'com.github.huluti.Curtail'
@@ -36,7 +37,7 @@ class CurtailWindow(Adw.ApplicationWindow):
     _settings = Gio.Settings.new(SETTINGS_SCHEMA)
     settings = Gtk.Settings.get_default()
 
-    prefs_window = None
+    prefs_dialog = None
     apply_window = None
 
     headerbar = Gtk.Template.Child()
@@ -101,6 +102,7 @@ class CurtailWindow(Adw.ApplicationWindow):
     def create_actions(self):
         self.create_simple_action('select-file', self.on_select, '<Primary>o')
         self.create_simple_action('clear-results', self.clear_results)
+        self.create_simple_action('banner-change-mode', self.banner_change_mode)
         self.create_simple_action('preferences', self.on_preferences, '<Primary>comma')
         self.create_simple_action('about', self.on_about)
         self.create_simple_action('quit', self.on_quit, '<Primary>q')
@@ -197,8 +199,7 @@ class CurtailWindow(Adw.ApplicationWindow):
                 filenames = list()
                 for file in files:
                     filenames.append(file.get_uri())
-                final_filenames = self.handle_filenames(filenames)
-                self.compress_filenames(final_filenames)
+                self.compress_filenames(filenames)
 
         dialog.open_multiple(self, None, handle_response)
 
@@ -210,13 +211,8 @@ class CurtailWindow(Adw.ApplicationWindow):
                 if response == "compress":
                     filenames = list()
                     for folder in folders:
-                        images = get_image_files_from_folder(folder.get_path())
-
-                        for image in images:
-                            filenames.append(image.get_uri())
-
-                    final_filenames = self.handle_filenames(filenames)
-                    self.compress_filenames(final_filenames)
+                        filenames.append(folder.get_path())
+                    self.compress_filenames(filenames)
 
             try:
                 folders = dialog.select_multiple_folders_finish(result)
@@ -225,20 +221,20 @@ class CurtailWindow(Adw.ApplicationWindow):
             else:
                 warning_message_dialog = self._create_warning_dialog()
                 warning_message_dialog.connect("response", on_dir_dialog_response)
-                warning_message_dialog.show()
+                warning_message_dialog.present(self)
 
         dialog.select_multiple_folders(self, None, handle_response)
 
     def _create_warning_dialog(self):
         dialog = None
         if self._settings.get_boolean('new-file'):
-            dialog = Adw.MessageDialog.new(self,
+            dialog = Adw.AlertDialog.new(
                 _("Are you sure you want to compress images in these directories?"),
                 _("All of the images in the directories selected and their "
                 "subdirectories will be compressed. The original images will not "
                 "be modified."))
         else:
-            dialog = Adw.MessageDialog.new(self,
+            dialog = Adw.AlertDialog.new(
                 _("Are you sure you want to compress images in these directories?"),
                 _("All of the images in the directories selected and their "
                 "subdirectories will be compressed and overwritten!"))
@@ -261,9 +257,7 @@ class CurtailWindow(Adw.ApplicationWindow):
         filenames = []
         for file in files:
             filenames.append(file.get_uri())
-
-        final_filenames = self.handle_filenames(filenames)
-        self.compress_filenames(final_filenames)
+        self.compress_filenames(filenames)
 
     def handle_filenames(self, filenames):
         final_filenames = []
@@ -273,9 +267,13 @@ class CurtailWindow(Adw.ApplicationWindow):
 
             path = Path(filename)
             if path.is_dir():
-                for new_filename in path.rglob("*"):
-                    new_filename = self.clean_filename(new_filename)
-                    final_filenames.append(new_filename)
+                if self._settings.get_boolean('recursive'):
+                    images = get_image_files_from_folder_recursive(path)
+                else:
+                    images = get_image_files_from_folder(path)
+                for image in images:
+                    image = self.clean_filename(image)
+                    final_filenames.append(image)
             else:
                 final_filenames.append(filename)
 
@@ -307,6 +305,8 @@ class CurtailWindow(Adw.ApplicationWindow):
         return new_filename
 
     def compress_filenames(self, filenames):
+        filenames = self.handle_filenames(filenames)
+
         result_items = []
         for filename in filenames:
             error_message = False
@@ -348,22 +348,25 @@ class CurtailWindow(Adw.ApplicationWindow):
     def on_lossy_changed(self, switch, state):
         self._settings.set_boolean('lossy', switch.get_active())
 
+    def banner_change_mode(self, *args):
+        self._settings.set_boolean('new-file', True)
+        self.show_warning_banner()
+
     def on_preferences(self, *args):
-        if self.prefs_window is not None:
-            self.prefs_window.destroy()
-        self.prefs_window = CurtailPrefsWindow(self)
-        self.prefs_window.present()
+        if self.prefs_dialog is not None:
+            self.prefs_dialog.force_close()
+        self.prefs_dialog = CurtailPrefsDialog(self)
+        self.prefs_dialog.present(self)
 
     def on_about(self, *args):
-        about = Adw.AboutWindow(
-                    transient_for=self,
+        about = Adw.AboutDialog(
                     application_name='Curtail',
                     application_icon='com.github.huluti.Curtail',
                     developer_name='Hugo Posnic',
                     license_type=Gtk.License.GPL_3_0,
                     website='https://github.com/Huluti/Curtail',
                     issue_url='https://github.com/Huluti/Curtail/issues/new',
-                    version='1.9.1',
+                    version='1.10.0',
                     developers=[
                         'Hugo Posnic https://github.com/Huluti'
                     ],
@@ -386,7 +389,7 @@ class CurtailWindow(Adw.ApplicationWindow):
             ]
         )
         about.set_debug_info(debug_infos())
-        about.present()
+        about.present(self)
 
     def on_quit(self, *args):
         self.app.quit()
